/**
 * The tag component is used to display a small piece of information in a coloured pill-shaped box.
 * */
export default {
  title: 'Components/Tag',
  tags: ['autodocs'],
  argTypes: {
    text: {
      control: 'text',
    },
    variant: {
      control: 'select',
      description: 'The variant of the tag. Is ignored if you add a custom modifier.',
      options: ['default', 'information', 'success', 'warning', 'error'],
      mapping: {
        default: '',
        information: 'rpf-tag--information',
        success: 'rpf-tag--success',
        warning: 'rpf-tag--warning',
        error: 'rpf-tag--error',
      },
    },
    secondary: {
      control: 'boolean',
      description: 'The secondary (inverted) look of all variants.',
    },
    icon: {
      control: 'text',
      description: 'A list of available icon names can be found [here](https://fonts.google.com/icons). Write names as snake case (so "Check Circle" becomes check_circle).',
    },
    iconPosition: {
      control: 'select',
      options: ['left', 'right'],
    },
  },
  args: {
    text: 'Button text',
    variant: 'default',
    secondary: false,
    icon: '',
    iconPosition: 'left',
  },
}

const TagTemplate = ({ text, secondary, icon, iconPosition, variant }) => {
  const className = [
    'rpf-tag',
    variant,
  ]
    .filter((n) => n)
    .join(' ')

  const iconSpan = (icon) => (icon ? `<span class='rpf-tag__icon material-symbols-sharp'>${icon}</span>` : '')

  return `
  <span class="${className} ${secondary ? 'rpf-tag--secondary' : ''}">
    ${(iconPosition === 'left' && icon != '') ? iconSpan(icon) : ''}
    ${text}
    ${(iconPosition === 'right' && icon != '') ? iconSpan(icon) : ''}
  </span>`
}

export const Default = TagTemplate.bind({})
Default.args = {
  text: 'Some text',
}

export const WithIconLeft = TagTemplate.bind({})
WithIconLeft.args = {
  text: 'Some text',
  icon: 'check_circle',
  iconPosition: 'left',
}

export const WithIconRight = TagTemplate.bind({})
WithIconRight.args = {
  text: 'Some text',
  icon: 'check_circle',
  iconPosition: 'right',
}

export const Information = TagTemplate.bind({})
Information.args = {
  text: 'Some text',
  variant: 'information',
}

export const Success = TagTemplate.bind({})
Success.args = {
  text: 'Some text',
  variant: 'success',
}

export const Warning = TagTemplate.bind({})
Warning.args = {
  text: 'Some text',
  variant: 'warning',
}

export const Error = TagTemplate.bind({})
Error.args = {
  text: 'Some text',
  variant: 'error',
}

export const SecondaryError = TagTemplate.bind({})
SecondaryError.args = {
  text: 'Some text',
  variant: 'error',
  secondary: true,
}

