import classNames from 'classnames'
/**
 * This is a single checkbox input field.
 *
 * It will sometimes be part of a [fieldset](/?path=/docs/components-form-fieldset--default).
 *
 * **Note:** Make sure to include a label for this input.
 *
 * [Designs](https://www.figma.com/file/k8HLf9t06G8QtlMzQlgHGk/RPF-Design-System---Component-Library?type=design&node-id=833-2522&mode=design&t=8WXVu4Nk5Ar3JL3U-4)
 * */
export default {
  title: 'Components/Form/CheckboxInput',
  tags: ['autodocs'],
  argTypes: {
    checked: { control: 'boolean', },
    disabled: { control: 'boolean', },
    error: { control: 'boolean' },
    fullWidth: { control: 'boolean' },
  },
  args: {
    checked: false,
    disabled: false,
    error: false,
    fullWidth: false,
  },
}

const TextTemplate = ({ checked, disabled, error, fullWidth }) => {
  const classnames_label = classNames('rpf-input-checkbox', {
    'rpf-input-checkbox--error': error,
    'rpf-input-checkbox--disabled': disabled,
    'rpf-input--full-width': fullWidth,
  })

  return `
     <label class="${classnames_label} ">
        <input type="checkbox" name="accept_terms" value="1" ${checked ? ' checked' : ''} ${disabled ? ' disabled' : ''} />
        I accept the terms
      </label>
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">error</span>Error: You must accept the terms</div>'
          : ''
      }`
}

export const Default = TextTemplate.bind({})
Default.args = {}

export const Error = TextTemplate.bind({})
Error.args = {
  error: true,
}

export const Disabled = TextTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const Checked = TextTemplate.bind({})
Checked.args = {
  checked: true,
}

export const FullWidth = TextTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}

export const DisabledAndFullWidth = TextTemplate.bind({})
DisabledAndFullWidth.args = {
  disabled: true,
  fullWidth: true,
}
