import classNames from 'classnames'

import '../../scss/components/forms/inputs.scss'
import '../../scss/components/forms/input-label.scss'
import '../../scss/components/forms/input-search.scss'
import '../../scss/components/forms/error-message.scss'

/**
 * The standard form search input, shown here with a label, hint, and where applicable an error message.
 * */

export default {
  title: 'Components/Form/SearchInput',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    placeholder: {
      control: 'text',
      description:
        'Try to avoid placeholder text where possible, it can be a usability issue as it disappears when the user starts typing.',
    },
    error: {
      control: 'boolean',
    },
  },
  args: {
    disabled: false,
    placeholder: '',
    error: false,
  },
}

const SearchTemplate = ({ disabled, placeholder, error }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_text = classNames('rpf-input rpf-input-search', {
    'rpf-input--disabled': disabled,
    'rpf-input--error': error,
  })
  const classnames_button = classNames('rpf-button rpf-button--icon-only', {
    'rpf-button--disabled': disabled,
    'rpf-button--error': error,
  })

  return `
    <div class="${classnames_wrapper}">
      <label for="search" class="${classnames_label}">
        Search for blogs
        <small class="rpf-label__hint">Please enter a search term</small>
      </label>
      <div class="rpf-input-search-container">
        <input type="search" id="search-input" name="search" aria-label="Search" class="${classnames_text}"${disabled ? ' disabled' : ''} placeholder="${placeholder}">
        <button class="${classnames_button}"${disabled ? ' disabled' : ''} onclick="">
          <span class="rpf-button__icon material-symbols-sharp">
            search
          </span>
        </button>
      </div>
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">info</span>Error: Search term is required</div>'
          : ''
      }
    </div>
  `
}

export const Default = SearchTemplate.bind({})
Default.args = {}

export const Error = SearchTemplate.bind({})
Error.args = {
  error: true,
}

export const Disabled = SearchTemplate.bind({})
Disabled.args = {
  disabled: true,
}
