/**
 * `MenuItem`'s are used within a `Menu` component. They can be buttons or links.
 * */
export default {
  title: 'Components/Menu/MenuItem',
  tags: ['autodocs'],
  argTypes: {
    danger: {
      control: 'boolean',
    },
    href: {
      control: 'text',
    },
    text: {
      control: 'text',
    },
    icon: {
      control: 'text',
      description: 'Icon names can be found [here](https://fonts.google.com/icons)',
    },
    iconPosition: {
      control: 'radio',
      options: ['left', 'right'],
    },
  },
  args: {
    text: 'Menu Item',
    href: '',
    danger: false,
    icon: '',
    iconPosition: 'left',
  },
}

const iconSpan = (icon) => (icon ? `<span class="rpf-button__icon material-symbols-sharp">${icon}</span>` : '')

const InnerTemplate = ({ text, iconPosition, icon }) => {
  return `
    ${iconPosition === 'left' && icon != '' ? iconSpan(icon) : ''}
    ${text}
    ${iconPosition === 'right' && icon != '' ? iconSpan(icon) : ''}
     `
}

const MenuItemTemplate = ({ danger, href, text, iconPosition, icon }) => {
  return `
    <ul>
      <li class="rpf-menu__item ${danger ? 'rpf-menu__item--danger' : ''}">
        ${
          href
            ? `<a href=${href}>${InnerTemplate({ text, iconPosition, icon })}</a>`
            : `<button>${InnerTemplate({ text, iconPosition, icon })}</button>`
        }
      </li>
    </ul>`
}

export const Default = MenuItemTemplate.bind({})
Default.args = {}

export const Link = MenuItemTemplate.bind({})
Link.args = {
  href: 'https://example.com',
}

export const Icon = MenuItemTemplate.bind({})
Icon.args = {
  icon: 'sentiment_satisfied',
}
